#pragma GCC optimize("Ofast")
#include <iostream>
#include <algorithm>
#include <iomanip>
#include <vector>
#include <set>
#include <bitset>
#include <cmath>
using namespace std;

typedef long long ll;

struct Point {
	int x, y;
	Point() {

	}
	Point(int _x, int _y) {
		x = _x;
		y = _y;
	}
};

Point operator-(Point a, Point b) {
	return Point(a.x - b.x, a.y - b.y);
}

bool operator < (Point a, Point b) {
	return make_pair(a.x, a.y) < make_pair(b.x, b.y);
}
bool operator == (Point a, Point b) {
	return make_pair(a.x, a.y) == make_pair(b.x, b.y);
}

double Q(double x) {
	return x * x;
}

double dist(double x1, double y1, double x2, double y2) {
	return sqrt(Q(x1 - x2) + Q(y1 - y2));
}

ll cross_product(Point a, Point b) {
	return (ll)a.x * b.y - (ll)b.x * a.y;
}

bool cmp(Point a, Point b) {
	return a < b;
}

bool cw(Point a, Point b, Point c) {
	return (ll)a.x * (b.y - c.y) + (ll)b.x * (c.y - a.y) + (ll)c.x * (a.y - b.y) < 0;
}

bool ccw(Point a, Point b, Point c) {
	return (ll)a.x * (b.y - c.y) + (ll)b.x * (c.y - a.y) + (ll)c.x * (a.y - b.y) > 0;
}

void convex_hull(vector<Point>&a) {
	if (a.size() == 1) {
		return;
	}

	sort(a.begin(), a.end(), &cmp);

	Point p1 = a[0], p2 = a.back();
	vector<Point>up, down;
	up.push_back(p1);
	down.push_back(p1);
	for (int i = 1; i < a.size(); i++) {
		if (i == a.size() - 1 || cw(p1, a[i], p2)) {
			while (up.size() >= 2 && !cw(up[up.size() - 2], up[up.size() - 1], a[i])) {
				up.pop_back();
			}
			up.push_back(a[i]);
		}
		if (i == a.size() - 1 || ccw(p1, a[i], p2)) {
			while (down.size() >= 2 && !ccw(down[down.size() - 2], down[down.size() - 1], a[i])) {
				down.pop_back();
			}
			down.push_back(a[i]);
		}
	}
	a.clear();
	for (int i = 0; i < up.size(); i++) {
		a.push_back(up[i]);
	}
	for (int i = down.size() - 2; i > 0; i--) {
		a.push_back(down[i]);
	}
}

int main() {
	ios_base::sync_with_stdio(0);
	cin.tie(0);
	int n, l;
	cin >> n >> l;
	vector<Point>pnt;
	for (int i = 0; i < n; i++) {
		int x, y;
		cin >> x >> y;
		pnt.emplace_back(x - l, y);
		pnt.emplace_back(x, y - l);
		pnt.emplace_back(x, y + l);
		pnt.emplace_back(x + l, y);
	}
	sort(pnt.begin(), pnt.end());
	pnt.resize(unique(pnt.begin(), pnt.end()) - pnt.begin());
	convex_hull(pnt);
	double res = 0;
	for (int i = 0; i < pnt.size(); i++) {
		res += dist(pnt[i].x, pnt[i].y, pnt[(i + 1) % pnt.size()].x, pnt[(i + 1) % pnt.size()].y);
	}
	cout << fixed << setprecision(10) << res;
	return 0;
}